@@ -1,17 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-"""Aestimo's database module. Contains a materialproperty dict containing 
-sub-dicts of values for each material and similar alloyproperty dict for the
-alloys of the materials. See the source for details on the required keys for
-each material or alloy.
 
- References:
-  - GaAs,AlAs parameters:
-    Properties of Semiconductor Alloys: Group-IV, III-V and II-VI Semiconductors Sadao AdAchi?2009 John Wiley & Sons, Ltd.
-    Basic Semiconductor Physics Second Edition,Prof. Chihiro Hamaguchi 2010 Springer
-    Physics of Optoelectronic Devices ,S-L.CHUANG ,1995 by John Wiley & Sons. Inc
-  
-"""
 """
  Aestimo 1D Schrodinger-Poisson Solver
  Copyright (C) 2013-2016 Sefer Bora Lisesivdin and Aestimo group
@@ -30,6 +19,19 @@ each material or alloy.
     along with this program. See ~/COPYING file or http://www.gnu.org/copyleft/gpl.txt .
 
     For the list of contributors, see ~/AUTHORS
+    
+    INFORMATION:
+    Aestimo's database module. Contains a materialproperty dict containing 
+    sub-dicts of values for each material and similar alloyproperty dict for the
+    alloys of the materials. See the source for details on the required keys for
+    each material or alloy.
+
+    REFERENCES:
+  - GaAs,AlAs parameters:
+    Properties of Semiconductor Alloys: Group-IV, III-V and II-VI Semiconductors Sadao AdAchi?2009 John Wiley & Sons, Ltd.
+    Basic Semiconductor Physics Second Edition,Prof. Chihiro Hamaguchi 2010 Springer
+    Physics of Optoelectronic Devices ,S-L.CHUANG ,1995 by John Wiley & Sons. Inc
+  
 """
 
 # MATERIAL PROPERTIES
@@ -54,6 +56,7 @@ materialproperty = {
 'C11':11.879, # (GPa) Elastic Constants
 'C12':5.376, # (GPa) Elastic Constants
 'a0':5.6533, # (A)Lattice constant
+'a0_sub':5.6533,
 'Ac':-7.17, # (eV) deformation potentials (Van de Walle formalism)
 'Av':1.16, # (eV) deformation potentials (Van de Walle formalism)
 'B':-1.7, # (eV) shear deformation potential (Van de Walle formalism)
@@ -84,7 +87,8 @@ materialproperty = {
 'GA3':1.29, 
 'C11':11.879,
 'C12':5.376,
-'a0':5.66, 
+'a0':5.66,
+'a0_sub':5.6533,
 'Ac':-5.64,
 'Av':2.47,
 'B':-1.5,
@@ -116,7 +120,8 @@ materialproperty = {
 'GA3':9.1,
 'C11':8.329,
 'C12':4.526,
-'a0':6.0584,
+'a0':6.0583,
+'a0_sub':5.6533,
 'Ac':-5.08,
 'Av':1.0,
 'B':-1.8,
@@ -149,6 +154,7 @@ materialproperty = {
 'C11':8.329,
 'C12':4.526,
 'a0':5.8688,
+'a0_sub':5.6533,
 'Ac':-5.04,
 'Av':1.27,
 'B':-1.7,
@@ -181,6 +187,7 @@ materialproperty = {
 'C11':14.05,
 'C12':6.203,
 'a0':5.4505,
+'a0_sub':5.6533,
 'Ac':-7.14,
 'Av':1.70,
 'B':-1.8,
@@ -213,6 +220,7 @@ materialproperty = {
 'C11':15.0,
 'C12':6.42,
 'a0':5.4635,
+'a0_sub':5.6533,
 'Ac':-5.54,
 'Av':3.15,
 'B':-1.5,
@@ -535,7 +543,8 @@ materialproperty = {
 'C11':16.6,
 'C12':6.4,
 'C44':7.96,
-'a0':5.431, 
+'a0':5.431,
+'a0_sub':5.4315,  # Just added as near value of a0 
 'Ac':-5.64,
 'Av':2.47,
 'B':-1.5,
@@ -568,7 +577,8 @@ materialproperty = {
 'C11':12.60,
 'C12':4.4,
 'C44':6.77,
-'a0':5.658, 
+'a0':5.658,
+'a0':5.6585, # Just added as near value of a0 
 'Ac':-5.64,
 'Av':2.47,
 'B':-1.5,
